What’s New — pvlab 0.1.0.dev1 documentation

# What’s New

See what’s new in the latest release of `pvlab` project.

(check README.rst for a general description of the project and its content).

Release History

- 1. Release 0.1.0

Technology - CIEMAT (Madrid, Spain) .. |control| replace:: control device .. |cwd| replace:: current working directory .. |dut| replace:: device under test .. |lab| replace:: PVLab .. |refpyr| replace:: reference device .. |version_str| replace:: version 0.1.0.dev1